@@ -12,6 +12,7 @@ import time
 import requests
 import sqlite3
 from datetime import date
+from hiveengine.api import Api
 from hiveengine.wallet import Wallet
 
 ### Global configuration
@@ -31,6 +32,8 @@ HIVE = Hive(node=[HIVE_API_NODE], keys=[config['Global']['ACCOUNT_ACTIVE_KEY']])
 HIVE.chain_params['chain_id'] = 'beeab0de00000000000000000000000000000000000000000000000000000000'
 beem.instance.set_shared_blockchain_instance(HIVE)
 
+setApi = Api(url = "https://engine.rishipanthee.com")
+
 ACCOUNT = Account(ACCOUNT_NAME)
 TOKEN_NAME = config['HiveEngine']['TOKEN_NAME']
 
@@ -188,7 +191,7 @@ def daily_limit_unique_reached(invoker_name, recipient_name, level=1):
 def get_invoker_level(invoker_name):
 
     # check how much TOKEN the invoker has
-    wallet_token_info = Wallet(invoker_name, api='https://engine.rishipanthee.com/').get_token(TOKEN_NAME)
+    wallet_token_info = Wallet(invoker_name, api=setApi).get_token(TOKEN_NAME)
 
     try:
         invoker_delegationsIn = float(wallet_token_info['delegationsIn'])
@@ -352,7 +355,7 @@ def main():
         # check how much TOKEN the bot has
         TOKEN_GIFT_AMOUNT = float(config['HiveEngine']['TOKEN_GIFT_AMOUNT'])
         
-        bot_balance = float(Wallet(ACCOUNT_NAME, api='https://engine.rishipanthee.com/').get_token(TOKEN_NAME)['balance'])
+        bot_balance = float(Wallet(ACCOUNT_NAME, api=setApi).get_token(TOKEN_NAME)['balance'])
         if bot_balance < TOKEN_GIFT_AMOUNT:
 
             message_body = 'Bot wallet has run out of %s' % TOKEN_NAME
@@ -368,7 +371,7 @@ def main():
         if ENABLE_TRANSFERS:
             print('[*] Transfering %f %s from %s to %s' % (TOKEN_GIFT_AMOUNT, TOKEN_NAME, ACCOUNT_NAME, parent_author))
 
-            wallet = Wallet(ACCOUNT_NAME, api='https://engine.rishipanthee.com/', blockchain_instance=HIVE)
+            wallet = Wallet(ACCOUNT_NAME, api=setApi, blockchain_instance=HIVE)
             wallet.stake(TOKEN_GIFT_AMOUNT, TOKEN_NAME, receiver=parent_author)
 
             today = str(date.today())
